import axios from 'axios'
import router from '../router'
import store from '@/store'
import storage from 'store'
import notification from 'ant-design-vue/es/notification'
import { VueAxios } from './axios'
import { LOGIN_TOKEN } from '@/store/mutation-types'
import Exception from '@/components/Exception/type'

const SUCCESS_CODE = '200'
const INVALID_LOGIN_TOKEN_CODE = '0004'
// const whiteList = ['/security/accessToken/get']
const loginPath = '/user/login'

const toast = (msg, description) => {
  notification.error({
    message: msg,
    description: description
  })
}
console.log(process.env.VUE_APP_API_BASE_URL)
// 创建 axios 实例
const request = axios.create({
  // API 请求的默认前缀
  baseURL: process.env.VUE_APP_API_BASE_URL,
  timeout: 6000 // 请求超时时间
})

// 处理网络异常
const errorHandler = (error) => {
  if (error.response && error.response.status) {
    const status = error.response.status
    if (status === 401) {
      store.dispatch('Logout').then(() => {
        router.push({
          path: loginPath
        })
      })
    } else {
      toast(status, Exception[status] ? Exception[status].desc : '访问接口服务异常')
    }
  }
  return Promise.reject(error)
}

// request interceptor
request.interceptors.request.use(config => {
  const loginToken = storage.get(LOGIN_TOKEN)
  if (loginToken) {
    config.headers[LOGIN_TOKEN] = loginToken
  }
  if (config.method === 'post' && config.headers['Content-Type'] !== 'application/x-www-form-urlencoded') {
    if (!config.data) {
      config.data = {}
    }
  }
  return config
}, errorHandler)

// response interceptor
request.interceptors.response.use((response) => {
  console.log(response)
  if (response.status === 200 && response.data.code === SUCCESS_CODE) {
    return Promise.resolve(response.data)
  } else if (response.data && response.data.code === INVALID_LOGIN_TOKEN_CODE) {
    toast('认证失败:', '登录超时，请重新登录')
    store.dispatch('Logout').then(() => {
      router.push({
        path: loginPath
      })
    })
    return Promise.reject(new Error(INVALID_LOGIN_TOKEN_CODE))
  } else {
    if (response.data && response.data.msg) toast(response.data.msg)
    return Promise.reject(response)
  }
}, errorHandler)

const installer = {
  vm: {},
  install (Vue) {
    Vue.use(VueAxios, request)
  }
}

export default request

export {
  installer as VueAxios,
  request as axios
}
